Quantcast

Convert alliance vanguard and horde expedition down from two entries to one entry. Will only affect the mechao-hog and mekgineer's chooper.

ackis [02-05-09 - 19:55]
Convert alliance vanguard and horde expedition down from two entries to one entry.  Will only affect the mechao-hog and mekgineer's chooper.
Filename
ARLConfig.lua
ARLFrame.lua
AckisRecipeList.lua
Docs/Documentation.txt
RecipeDB/ARL-Engineer.lua
diff --git a/ARLConfig.lua b/ARLConfig.lua
index de69d4e..3311e07 100644
--- a/ARLConfig.lua
+++ b/ARLConfig.lua
@@ -28,6 +28,7 @@ local AceConfigDialog 	= LibStub("AceConfigDialog-3.0")
 local modularOptions = {}
 local nagrandfac = BFAC["Kurenai"] .. "\\" .. BFAC["The Mag'har"]
 local hellfirefac = BFAC["Honor Hold"] .. "\\" .. BFAC["Thrallmar"]
+local howlingtundra = BFAC["Alliance Vanguard"] .. "\\" .. BFAC["Horde Expedition"]
 local addonversion = GetAddOnMetadata("AckisRecipeList", "Version")

 -- Description: Function which provides "profiles" options table
@@ -793,7 +794,6 @@ local function giveFilter()
 								},
 							},
 						},
--- Below this is WotLK stuff. May need to be changed post beta
 						WotLK = {
 							order	= 5,
 							type	= "group",
@@ -815,14 +815,6 @@ local function giveFilter()
 									type	= "description",
 									name	= L["FILTERING_WOTLK_DESC"] .. "\n",
 								},
-								AllianceVanguard = {
-									order	= 9,
-									type	= "toggle",
-									name	= BFAC["Alliance Vanguard"],
-									desc	= format(L["SPECIFIC_REP_DESC"],BFAC["Alliance Vanguard"]),
-									get		= function() return addon.db.profile.filters.rep.alliancevanguard end,
-									set		= function() addon.db.profile.filters.rep.alliancevanguard = not addon.db.profile.filters.rep.alliancevanguard end,
-								},
 								ArgentCrusade = {
 									order	= 10,
 									type	= "toggle",
@@ -839,13 +831,13 @@ local function giveFilter()
 									get		= function() return addon.db.profile.filters.rep.frenzyheart end,
 									set		= function() addon.db.profile.filters.rep.frenzyheart = not addon.db.profile.filters.rep.frenzyheart end,
 								},
-								HordeExpidition = {
-									order	= 15,
+								WrathCommon1 = {
+									order	= 12,
 									type	= "toggle",
-									name	= BFAC["Horde Expedition"],
-									desc	= format(L["SPECIFIC_REP_DESC"],BFAC["Horde Expedition"]),
-									get		= function() return addon.db.profile.filters.rep.hordeexpedition end,
-									set		= function() addon.db.profile.filters.rep.hordeexpedition = not addon.db.profile.filters.rep.hordeexpedition end,
+									name	= howlingtundra,
+									desc	= format(L["SPECIFIC_REP_DESC"],howlingtundra),
+									get		= function() return addon.db.profile.filters.rep.wrathcommon1 end,
+									set		= function() addon.db.profile.filters.rep.wrathcommon1 = not addon.db.profile.filters.rep.wrathcommon1 end,
 								},
 								EbonBlade = {
 									order	= 16,
diff --git a/AckisRecipeList.lua b/AckisRecipeList.lua
index 44c1b15..937eb8e 100644
--- a/AckisRecipeList.lua
+++ b/AckisRecipeList.lua
@@ -70,7 +70,7 @@ end
 local BFAC		= LibStub("LibBabble-Faction-3.0"):GetLookupTable()

 -- Change this if new filters are added ever
-local MaxFilterIndex = 131
+local MaxFilterIndex = 130

 -- Global Frame Variables
 addon.optionsFrame = {}
@@ -257,8 +257,7 @@ function addon:OnInitialize()
 					handofvengeance = true,
 					taunka = true,
 					warsongoffensive = true,
-					hordeexpedition = true,
-					alliancevanguard = true,
+					wrathcommon1 = true,
 				}
 			}
 		}
@@ -858,8 +857,7 @@ do
 			[127] = repdb.handofvengeance,
 			[128] = repdb.taunka,
 			[129] = repdb.warsongoffensive,
-			[130] = repdb.hordeexpedition,
-			[131] = repdb.alliancevanguard,
+			[130] = repdb.wrathcommon1,
 		}

 	end
diff --git a/Docs/Documentation.txt b/Docs/Documentation.txt
index f149b0a..36e7b85 100644
--- a/Docs/Documentation.txt
+++ b/Docs/Documentation.txt
@@ -215,9 +215,7 @@ A recipe can be flagged with many (or even all) of the below flags. They are def
 *127 = The Hand of Vengeance
 *128 = The Taunka
 *129 = Warsong Offensive
-*130 = Horde Expedition
-*131 = Alliance Vanguard
-
+*130 = Wrath Common Factions (Alliance Vanguard/Horde Expedition)

 ==Acquire Flags==

diff --git a/RecipeDB/ARL-Engineer.lua b/RecipeDB/ARL-Engineer.lua
index 579dd30..1357b9a 100644
--- a/RecipeDB/ARL-Engineer.lua
+++ b/RecipeDB/ARL-Engineer.lua
@@ -1703,7 +1703,7 @@ function addon:InitEngineering(RecipeDB)
 	-- Mekgineer's Chopper -- 60867
 	recipecount = recipecount + 1
 	self:addTradeSkill(RecipeDB,60867,450,44413,4,4036)
-	self:addTradeFlags(RecipeDB,60867,1,4,21,22,23,24,25,26,27,28,29,30,36,41,131)
+	self:addTradeFlags(RecipeDB,60867,1,4,21,22,23,24,25,26,27,28,29,30,36,41,130)
 	self:addTradeAcquire(RecipeDB,60867,6,1037,4,32564,6,1037,4,32773)

 	-- Nesingwary 4000 -- 60874
diff --git a/ARLFrame.lua b/ARLFrame.lua
index 40fd8c4..5f8eaff 100644
--- a/ARLFrame.lua
+++ b/ARLFrame.lua
@@ -2809,7 +2809,7 @@ function addon.setFlyawayState()
 	ARL_RepShatteredSunCB:SetChecked(filterdb.rep.shatteredsun)
 	ARL_RepSporeggarCB:SetChecked(filterdb.rep.sporeggar)
 	ARL_RepVioletEyeCB:SetChecked(filterdb.rep.violeteye)
--- Below this is WotLK stuff. May need to be changed post beta.
+	-- WotLK Rep Options
 	ARL_RepArgentCrusadeCB:SetChecked(filterdb.rep.argentcrusade)
 	ARL_RepFrenzyheartCB:SetChecked(filterdb.rep.frenzyheart)
 	ARL_RepEbonBladeCB:SetChecked(filterdb.rep.ebonblade)
@@ -2825,8 +2825,7 @@ function addon.setFlyawayState()
 	ARL_RepHandOfVengeanceCB:SetChecked(filterdb.rep.handofvengeance)
 	ARL_RepTaunkaCB:SetChecked(filterdb.rep.taunka)
 	ARL_RepWarsongOffensiveCB:SetChecked(filterdb.rep.warsongoffensive)
-	ARL_RepAllianceVanguardCB:SetChecked(filterdb.rep.alliancevanguard)
-	ARL_RepHordeExpeditionCB:SetChecked(filterdb.rep.hordeexpedition)
+	ARL_RepAllianceVanguardCB:SetChecked(filterdb.rep.wrathcommon1)
 end

 -- Description:
@@ -3273,6 +3272,7 @@ function addon:CreateFrame(

 	local HonorHold_Thrallmar_FactionText = ""
 	local Kurenai_Maghar_FactionText = ""
+	local Vanguard_Expedition_FactionText = ""

 	-- Values for the progressbar (defaults)
 	local pbMin = 0
@@ -3310,15 +3310,13 @@ function addon:CreateFrame(
 	-- Adding a check in to see if we're Horde or Alliance, and change the displayed reputation
 	-- strings to be faction correct (eg, Honor Hold / Thrallmar)
 	if (myFaction == "Alliance") then
-
 		HonorHold_Thrallmar_FactionText = BFAC["Honor Hold"]
 		Kurenai_Maghar_FactionText = BFAC["Kurenai"]
-
+		Vanguard_Expedition_FactionText = BFAC["Alliance Vanguard"]
 	else
-
 		HonorHold_Thrallmar_FactionText = BFAC["Thrallmar"]
 		Kurenai_Maghar_FactionText = BFAC["The Mag'har"]
-
+		Vanguard_Expedition_FactionText = BFAC["Horde Expidition"]
 	end

 	if (not addon.Frame) then
@@ -4098,7 +4096,7 @@ function addon:CreateFrame(
 				ARL_RepVioletEyeCBText:SetText(BFAC["The Violet Eye"])
 				ARL_RepVioletEyeCBText:SetFont(narrowFont, 11)

-			-- Everything below here is WotLK stuff. May need to be changed after beta.
+			-- WotLK
 			addon.Fly_Rep_LK= CreateFrame("Frame", "addon.Fly_Rep_LK", addon.Fly_Rep)
 			addon.Fly_Rep_LK:SetWidth(150)
 			addon.Fly_Rep_LK:SetHeight(280)
@@ -4122,8 +4120,7 @@ function addon:CreateFrame(
 --			() The Hand of Vengeance
 --			() The Taunka
 --			() Warsong Offensive
 --			() Alliance Vanguard
 --			() Horde Expedition
 			local ARL_RepArgentCrusadeCB = CreateFrame("CheckButton", "ARL_RepArgentCrusadeCB", addon.Fly_Rep_LK, "UICheckButtonTemplate")
 				addon:GenericMakeCB(ARL_RepArgentCrusadeCB, addon.Fly_Rep_LK,
 					sformat(L["SPECIFIC_REP_DESC"], BFAC["Argent Crusade"]), 69, 1, 1, 0)
@@ -4201,14 +4198,10 @@ function addon:CreateFrame(
 				ARL_RepWarsongOffensiveCBText:SetFont(narrowFont, 11)
 			local ARL_RepAllianceVanguardCB = CreateFrame("CheckButton", "ARL_RepAllianceVanguardCB", addon.Fly_Rep_LK, "UICheckButtonTemplate")
 				addon:GenericMakeCB(ARL_RepAllianceVanguardCB, addon.Fly_Rep_LK,
-					sformat(L["SPECIFIC_REP_DESC"], BFAC["Alliance Vanguard"]), 86, 16, 1, 0)
-				ARL_RepAllianceVanguardCBText:SetText(BFAC["Alliance Vanguard"])
+					sformat(L["SPECIFIC_REP_DESC"],  Vanguard_Expedition_FactionText), 86, 16, 1, 0)
+				ARL_RepAllianceVanguardCBText:SetText(Vanguard_Expedition_FactionText)
 				ARL_RepAllianceVanguardCBText:SetFont(narrowFont, 11)
-			local ARL_RepHordeExpeditionCB = CreateFrame("CheckButton", "ARL_RepHordeExpeditionCB", addon.Fly_Rep_LK, "UICheckButtonTemplate")
-				addon:GenericMakeCB(ARL_RepHordeExpeditionCB, addon.Fly_Rep_LK,
-					sformat(L["SPECIFIC_REP_DESC"], BFAC["Horde Expedition"]), 87, 17, 1, 0)
-				ARL_RepHordeExpeditionCBText:SetText(BFAC["Horde Expedition"])
-				ARL_RepHordeExpeditionCBText:SetFont(narrowFont, 11)
+

 		-- Now that everything exists, populate the global filter table
 		local filterdb = addon.db.profile.filters
@@ -4308,8 +4301,7 @@ function addon:CreateFrame(
 			[81] = { cb = ARL_RepHandOfVengeanceCB,		svroot = filterdb.rep,			svval = "handofvengeance" },
 			[82] = { cb = ARL_RepTaunkaCB,				svroot = filterdb.rep,			svval = "taunka" },
 			[83] = { cb = ARL_RepWarsongOffensiveCB,	svroot = filterdb.rep,			svval = "warsongoffensive" },
-			[86] = { cb = ARL_RepAllianceVanguardCB,	svroot = filterdb.rep,			svval = "alliancevanguard" },
-			[87] = { cb = ARL_RepHordeExpeditionCB,		svroot = filterdb.rep,			svval = "hordeexpedition" },
+			[86] = { cb = ARL_RepAllianceVanguardCB,	svroot = filterdb.rep,			svval = "wrathcommon1" },
 		}

 	end
@@ -4122,8 +4120,7 @@ function addon:CreateFrame(
 --			() The Taunka
 --			() Warsong Offensive
---			() Alliance Vanguard
---			() Horde Expedition
+--			() Alliance Vanguard / Horde Expidition
 			local ARL_RepArgentCrusadeCB = CreateFrame("CheckButton", "ARL_RepArgentCrusadeCB", addon.Fly_Rep_LK, "UICheckButtonTemplate")
 				addon:GenericMakeCB(ARL_RepArgentCrusadeCB, addon.Fly_Rep_LK,